Module tools

Module tools 

This module contains the APIs for the various services provided by the EBI and the NCBI.

The current services include:

  • Blast: The Basic Local Alignment Search Tool (BLAST) is used to find regions of local similarity between sequences.
  • Clustalo: Clustal Omega is a multiple sequence alignment program for proteins.

You can view a complete list of supported services here. Please feel free to open an issue or a pull request if you would like to see support for more services.

Re-exports

pub use blast::Blast;
pub use blast::BlastResult;
pub use blast::Description;
pub use blast::Hit;
pub use blast::Hsp;
pub use msa::Clustalo;
pub use msa::ClustaloResult;

Modules

blast
msa

Structs

EbioticClient
The EbioticReqwestClient struct is used to specify the Reqwest client for the Ebiotic API.
Reader
A FASTA reader.
Record
A FASTA record.

Constants

BLAST_ENDPOINT
EBI_TOOLS_ENDPOINT

Traits

Service